==> react-molecule-tabs-2.28.0.tgz: package/lib/components/MoleculeTab.js <==
import { useEffect, useRef } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import { useOnScreen } from '@s-ui/react-hooks';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var BASE_CLASS = "sui-MoleculeTabs";
var CLASS_TAB = BASE_CLASS + "-item";
var CLASS_TAB_ICON = CLASS_TAB + "-icon";
var CLASS_TAB_COUNT = CLASS_TAB + "-count";
/* status */

var CLASS_TAB_ACTIVE = "is-active";
var CLASS_TAB_DISABLED = "is-disabled";

var MoleculeTab = function MoleculeTab(_ref) {
  var _cx;

  var active = _ref.active,
      onChange = _ref.onChange,
      disabled = _ref.disabled,
      icon = _ref.icon,
      count = _ref.count,
      label = _ref.label,
      numTab = _ref.numTab;

  var _useOnScreen = useOnScreen(),
      isIntersecting = _useOnScreen[0],
      outerRef = _useOnScreen[1];

  var innerRef = useRef();

  var handleChange = function handleChange(ev) {
    !disabled && onChange(ev, {
      numTab: numTab
    });
  };

  useEffect(function () {
    if (active && isIntersecting) {
      innerRef.current.scrollIntoView({
        behavior: 'smooth',
        block: 'nearest',
        inline: 'start'
      });
    }
  }, [active, innerRef, isIntersecting]);
  var className = cx(CLASS_TAB, (_cx = {}, _cx[CLASS_TAB_ACTIVE] = active, _cx[CLASS_TAB_DISABLED] = disabled, _cx));
  return /*#__PURE__*/_jsxs("li", {
    className: className,
    onClick: handleChange,
    ref: useMergeRefs(innerRef, outerRef),
    children: [icon && /*#__PURE__*/_jsx("span", {
      className: CLASS_TAB_ICON,
      children: icon
    }), !isNaN(count) && /*#__PURE__*/_jsx("span", {
      className: CLASS_TAB_COUNT,
      children: count
    }), /*#__PURE__*/_jsx("span", {
      children: label
    })]
  });
};

export default MoleculeTab;

==> react-molecule-tabs-2.29.0.tgz: package/lib/components/MoleculeTab.js <==
import { useEffect, useRef, forwardRef } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import { CLASS_TAB, CLASS_TAB_ICON, CLASS_TAB_COUNT, CLASS_TAB_ACTIVE, CLASS_TAB_DISABLED } from './config';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var MoleculeTab = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _cx;

  var active = _ref.active,
      onChange = _ref.onChange,
      disabled = _ref.disabled,
      icon = _ref.icon,
      count = _ref.count,
      label = _ref.label,
      numTab = _ref.numTab,
      isIntersecting = _ref.isIntersecting;
  var innerRef = useRef();

  var handleChange = function handleChange(ev) {
    !disabled && onChange(ev, {
      numTab: numTab
    });
  };

  useEffect(function () {
    if (active && isIntersecting) {
      innerRef.current.scrollIntoView({
        behavior: 'smooth',
        block: 'nearest',
        inline: 'start'
      });
    }
  }, [active, isIntersecting, innerRef]);
  var className = cx(CLASS_TAB, (_cx = {}, _cx[CLASS_TAB_ACTIVE] = active, _cx[CLASS_TAB_DISABLED] = disabled, _cx));
  return /*#__PURE__*/_jsxs("li", {
    className: className,
    onClick: handleChange,
    ref: useMergeRefs(innerRef, forwardedRef),
    children: [icon && /*#__PURE__*/_jsx("span", {
      className: CLASS_TAB_ICON,
      children: icon
    }), !isNaN(count) && /*#__PURE__*/_jsx("span", {
      className: CLASS_TAB_COUNT,
      children: count
    }), /*#__PURE__*/_jsx("span", {
      children: label
    })]
  });
});
export default MoleculeTab;
